==> admob_flutter-0.3.1.tar.gz: ios/Classes/SwiftAdmobFlutterPlugin.swift <==
/*
 ISC License
 
 Copyright (c) 2019 Kevin McGill <kevin@mcgilldevtech.com>

 Permission to use, copy, modify, and/or distribute this software for any
 purpose with or without fee is hereby granted, provided that the above
 copyright notice and this permission notice appear in all copies.
 
 THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

import UIKit
import GoogleMobileAds

public class SwiftAdmobFlutterPlugin: NSObject, FlutterPlugin {
    
  public static func register(with registrar: FlutterPluginRegistrar) {
    let instance = SwiftAdmobFlutterPlugin()
    
    let defaultChannel = FlutterMethodChannel(name: "admob_flutter", binaryMessenger: registrar.messenger())
    registrar.addMethodCallDelegate(instance, channel: defaultChannel)
    
    registrar.register(
        AdmobBannerFactory(messeneger: registrar.messenger()),
        withId: "admob_flutter/banner"
    )
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "initialize":
        GADMobileAds.sharedInstance().start(completionHandler: nil)
        break
    default:
        result(FlutterMethodNotImplemented)
    }
  }
}

==> admob_flutter-0.3.4.tar.gz: ios/Classes/SwiftAdmobFlutterPlugin.swift <==
/*
 ISC License
 
 Copyright (c) 2019 Kevin McGill <kevin@mcgilldevtech.com>

 Permission to use, copy, modify, and/or distribute this software for any
 purpose with or without fee is hereby granted, provided that the above
 copyright notice and this permission notice appear in all copies.
 
 THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

import UIKit
import GoogleMobileAds

public class SwiftAdmobFlutterPlugin: NSObject, FlutterPlugin {
    
  public static func register(with registrar: FlutterPluginRegistrar) {
    let instance = SwiftAdmobFlutterPlugin()
    
    let defaultChannel = FlutterMethodChannel(name: "admob_flutter", binaryMessenger: registrar.messenger())
    registrar.addMethodCallDelegate(instance, channel: defaultChannel)
    
    registrar.register(
        AdmobBannerFactory(messeneger: registrar.messenger()),
        withId: "admob_flutter/banner"
    )
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "initialize":
        // https://developers.google.com/admob/ios/test-ads#enable_test_devices
        // **iOS simulators are automatically configured as test devices.**
        // GADMobileAds.sharedInstance().requestConfiguration.testDeviceIdentifiers = ["You're physical iDevice Id"]
        GADMobileAds.sharedInstance().start { (status: GADInitializationStatus) in
            print("iOS Admob status: \(status.adapterStatusesByClassName)")
        }
        break
    default:
        result(FlutterMethodNotImplemented)
    }
  }
}
